@@ -546,6 +546,8 @@ if __name__ == '__main__':
                          "sagemath-libecm",
                          "sagemath-singular",
                          "sagemath-linbox",
+                         "sagemath-m4ri-m4rie",
+                         "sagemath-iml",
                          "sagemath-flint",
                          "sagemath-ntl",
                          "sagemath-pari",
